==> estateplat-common-1.2.4-20220629.074349-1059-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSms.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author jiangganzhi <jiangganzhi@gtmap.cn>
 * @date 2022年06月17日
 * @description 不动产短信表
 */
@Table(name = "bdc_sms")
public class BdcSms {
    @Id
    private String id;
    private String xxnr;//消息内容
    private Date crsj;//插入时间
    private String sjr;//收件人
    private String sjrid;//收件人id
    private String sjhm;//收件号码
    private String sffdx;//是否发短信
    private Date fssj;//发送时间
    private String sfyd;//是否已读
    private Date dqsj;//读取时间
    private String sfcl;//是否处理
    private Date clsj;//处理时间
    private String xxlb;//消息类别
    private String yyslx;//运营商类型
    private String ywid;//业务ID

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getXxnr() {
        return xxnr;
    }

    public void setXxnr(String xxnr) {
        this.xxnr = xxnr;
    }

    public Date getCrsj() {
        return crsj;
    }

    public void setCrsj(Date crsj) {
        this.crsj = crsj;
    }

    public String getSjr() {
        return sjr;
    }

    public void setSjr(String sjr) {
        this.sjr = sjr;
    }

    public String getSjrid() {
        return sjrid;
    }

    public void setSjrid(String sjrid) {
        this.sjrid = sjrid;
    }

    public String getSjhm() {
        return sjhm;
    }

    public void setSjhm(String sjhm) {
        this.sjhm = sjhm;
    }

    public String getSffdx() {
        return sffdx;
    }

    public void setSffdx(String sffdx) {
        this.sffdx = sffdx;
    }

    public Date getFssj() {
        return fssj;
    }

    public void setFssj(Date fssj) {
        this.fssj = fssj;
    }

    public String getSfyd() {
        return sfyd;
    }

    public void setSfyd(String sfyd) {
        this.sfyd = sfyd;
    }

    public Date getDqsj() {
        return dqsj;
    }

    public void setDqsj(Date dqsj) {
        this.dqsj = dqsj;
    }

    public String getSfcl() {
        return sfcl;
    }

    public void setSfcl(String sfcl) {
        this.sfcl = sfcl;
    }

    public Date getClsj() {
        return clsj;
    }

    public void setClsj(Date clsj) {
        this.clsj = clsj;
    }

    public String getXxlb() {
        return xxlb;
    }

    public void setXxlb(String xxlb) {
        this.xxlb = xxlb;
    }

    public String getYyslx() {
        return yyslx;
    }

    public void setYyslx(String yyslx) {
        this.yyslx = yyslx;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }
}

==> estateplat-common-1.2.4-20230718.031041-1191-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSms.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author jiangganzhi <jiangganzhi@gtmap.cn>
 * @date 2022年06月17日
 * @description 不动产短信表
 */
@Table(name = "bdc_sms")
public class BdcSms {
    @Id
    private String id;
    private String xxnr;//消息内容
    private Date crsj;//插入时间
    private String sjr;//收件人
    private String sjrid;//收件人id
    private String sjhm;//收件号码
    private String sffdx;//是否发短信
    private Date fssj;//发送时间
    private String sfyd;//是否已读
    private Date dqsj;//读取时间
    private String sfcl;//是否处理
    private Date clsj;//处理时间
    private String xxlb;//消息类别
    private String yyslx;//运营商类型
    private String ywid;//业务ID
    private String qxdm;//区县代码

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getXxnr() {
        return xxnr;
    }

    public void setXxnr(String xxnr) {
        this.xxnr = xxnr;
    }

    public Date getCrsj() {
        return crsj;
    }

    public void setCrsj(Date crsj) {
        this.crsj = crsj;
    }

    public String getSjr() {
        return sjr;
    }

    public void setSjr(String sjr) {
        this.sjr = sjr;
    }

    public String getSjrid() {
        return sjrid;
    }

    public void setSjrid(String sjrid) {
        this.sjrid = sjrid;
    }

    public String getSjhm() {
        return sjhm;
    }

    public void setSjhm(String sjhm) {
        this.sjhm = sjhm;
    }

    public String getSffdx() {
        return sffdx;
    }

    public void setSffdx(String sffdx) {
        this.sffdx = sffdx;
    }

    public Date getFssj() {
        return fssj;
    }

    public void setFssj(Date fssj) {
        this.fssj = fssj;
    }

    public String getSfyd() {
        return sfyd;
    }

    public void setSfyd(String sfyd) {
        this.sfyd = sfyd;
    }

    public Date getDqsj() {
        return dqsj;
    }

    public void setDqsj(Date dqsj) {
        this.dqsj = dqsj;
    }

    public String getSfcl() {
        return sfcl;
    }

    public void setSfcl(String sfcl) {
        this.sfcl = sfcl;
    }

    public Date getClsj() {
        return clsj;
    }

    public void setClsj(Date clsj) {
        this.clsj = clsj;
    }

    public String getXxlb() {
        return xxlb;
    }

    public void setXxlb(String xxlb) {
        this.xxlb = xxlb;
    }

    public String getYyslx() {
        return yyslx;
    }

    public void setYyslx(String yyslx) {
        this.yyslx = yyslx;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }
}
